| Home | Libraries | People | FAQ | More

### add_cv

    template <class T>
    struct add_cv
    {
       typedef see-below type;
    };

type: The same type as `T const volatile` for all `T`.

C++ Standard Reference: 3.9.3.

Compiler Compatibility: If the compiler does not support partial specialization of class-templates then this template will compile, but the member `type` will always be the same as type `T` except where compiler workarounds have been applied.

Header: `#include <boost/type_traits/add_cv.hpp>` or `#include <boost/type_traits.hpp>`

Table 1.11. Examples

Expression | Result Type
--- | ---
`add_cv<int>::type` | `int const volatile`
`add_cv<int&>::type` | `int&`
`add_cv<int*>::type` | `int* const volatile`
`add_cv<int const>::type` | `int const volatile`